@@ -2,11 +2,13 @@ import torch
 
 
 class MultiLayerPerceptron(torch.nn.Module):
-    def __init__(self, num_features, num_classes, hidden_sizes=None, activations=None, flatten=True):
+    def __init__(self, num_features, num_classes, hidden_sizes=None, activations=None, dropout_probs=None, flatten=True):
         if hidden_sizes is None:
             hidden_sizes = []
         if activations is None:
-            activations = []
+            activations = ['ReLU']
+        if dropout_probs is None:
+            dropout_probs = [0]
 
         if type(activations) is str:
             activation_name = activations
@@ -15,6 +17,13 @@ class MultiLayerPerceptron(torch.nn.Module):
             activations *= len(hidden_sizes)
         assert len(activations) == len(hidden_sizes)
 
+        if type(dropout_probs) is int:
+            dropout_prob = dropout_probs
+            dropout_probs = [dropout_prob for _ in range(len(hidden_sizes))]
+        if len(dropout_probs) == 1:
+            dropout_probs *= len(hidden_sizes)
+        assert len(dropout_probs) == len(hidden_sizes)
+
         super().__init__()
 
         self.num_features = num_features
@@ -30,6 +39,9 @@ class MultiLayerPerceptron(torch.nn.Module):
             else:
                 self.model.append(torch.nn.Linear(hidden_sizes[i - 1], hidden_sizes[i]))
 
+            # Dropout
+            self.model.append(torch.nn.Dropout(dropout_probs[i]))
+
             # Activation
             if type(activations[i]) == str:
                 self.model.append(getattr(torch.nn, activations[i])())
